package dynamic
import "k8s.io/client-go/dynamic"
Index ¶
- func LegacyAPIPathResolverFunc(kind schema.GroupVersionKind) string
- type APIPathResolverFunc
- type Interface
- type NamespaceableResourceInterface
- type ResourceInterface
Functions ¶
func LegacyAPIPathResolverFunc ¶
func LegacyAPIPathResolverFunc(kind schema.GroupVersionKind) string
LegacyAPIPathResolverFunc can resolve paths properly with the legacy API. TODO find a better place to move this for existing callers
Types ¶
type APIPathResolverFunc ¶
type APIPathResolverFunc func(kind schema.GroupVersionKind) string
APIPathResolverFunc knows how to convert a groupVersion to its API path. The Kind field is optional. TODO find a better place to move this for existing callers
type Interface ¶
type Interface interface {
Resource(resource schema.GroupVersionResource) NamespaceableResourceInterface
}
func NewForConfig ¶
type NamespaceableResourceInterface ¶
type NamespaceableResourceInterface interface {
Namespace(string) ResourceInterface
ResourceInterface
}
type ResourceInterface ¶
type ResourceInterface interface {
Create(obj *unstructured.Unstructured, subresources ...string) (*unstructured.Unstructured, error)
Update(obj *unstructured.Unstructured, subresources ...string) (*unstructured.Unstructured, error)
UpdateStatus(obj *unstructured.Unstructured) (*unstructured.Unstructured, error)
Delete(name string, options *metav1.DeleteOptions, subresources ...string) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions, subresources ...string) (*unstructured.Unstructured, error)
List(opts metav1.ListOptions) (*unstructured.UnstructuredList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (*unstructured.Unstructured, error)
}
Source Files ¶
interface.go scheme.go simple.go
Directories ¶
| Path | Synopsis |
|---|---|
| dynamic/fake |
- Version
- v8.0.0+incompatible
- Published
- Jun 28, 2018
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 49 minutes ago –
Tools for package owners.