Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredDynamicInformer ¶
func NewFilteredDynamicInformer(client dynamic.Interface, gvr schema.GroupVersionResource, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions TweakListOptionsFunc) informers.GenericInformer
NewFilteredDynamicInformer constructs a new informer for a dynamic type.
Types ¶
type DynamicSharedInformerFactory ¶
type DynamicSharedInformerFactory interface {
// which run until the stop channel gets closed.
Start(stopCh <-chan struct{})
ForResource(gvr schema.GroupVersionResource) informers.GenericInformer
// or the stop channel gets closed.
WaitForCacheSync(stopCh <-chan struct{}) map[schema.GroupVersionResource]bool
// informers can be started anymore and Start will return without
// doing anything.
//
// In addition, Shutdown blocks until all goroutines have terminated. For that
// to happen, the close channel(s) that they were started with must be closed,
// either before Shutdown gets called or while it is waiting.
//
// Shutdown may be called multiple times, even concurrently. All such calls will
// block until all goroutines have terminated.
Shutdown()
}
DynamicSharedInformerFactory provides access to a shared informer and lister for dynamic client
func NewDynamicSharedInformerFactory ¶
func NewDynamicSharedInformerFactory(client dynamic.Interface, defaultResync time.Duration) DynamicSharedInformerFactory
NewDynamicSharedInformerFactory constructs a new instance of dynamicSharedInformerFactory for all namespaces.
func NewFilteredDynamicSharedInformerFactory ¶
func NewFilteredDynamicSharedInformerFactory(client dynamic.Interface, defaultResync time.Duration, namespace string, tweakListOptions TweakListOptionsFunc) DynamicSharedInformerFactory
NewFilteredDynamicSharedInformerFactory constructs a new instance of dynamicSharedInformerFactory. Listers obtained via this factory will be subject to the same filters as specified here.
type TweakListOptionsFunc ¶
type TweakListOptionsFunc func(*metav1.ListOptions)
TweakListOptionsFunc defines the signature of a helper function that wants to provide more listing options to API
Click to show internal directories.
Click to hide internal directories.